@@ -17,6 +17,14 @@ return (
    [osvers => qr{^10\.},
     [package => 'clang']]]],
 
+ [
+  cpanmod => ['FreeBSD::Version2'],
+  [os => 'freebsd',
+   [osvers => { '<', 10, '>=', 1 },
+    [package => 'gcc']],
+   [osvers => { '>=', 10 },
+    [package => 'clang']]]],
+
  [
   cpanmod => 'Multi::Packages',
   [package => ['package-one', 'package-two']]],
